## Typing stubs for pyluach

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`pyluach`](https://github.com/simlist/pyluach) package. It can be used by type checkers
to check code that uses `pyluach`. This version of
`types-pyluach` aims to provide accurate annotations for
`pyluach==2.2.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/pyluach`](https://github.com/python/typeshed/tree/main/stubs/pyluach)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.17.1
* [pyright](https://github.com/microsoft/pyright) 1.1.404

It was generated from typeshed commit
[`4fa56fbc236c99159c6132254d8f182598469df8`](https://github.com/python/typeshed/commit/4fa56fbc236c99159c6132254d8f182598469df8).